<?php

define ( 'jobtype_fax', 0 );
define ( 'jobtype_sms', 1 );
define ( 'jobtype_email', 2 );
define ( 'jobtype_iletter', 3 );
define ( 'jobtype_ilettercolor', 4 );
define ( 'jobtype_signature', 8 );

class faxdeclient extends soapclient {
	protected $UserId = "";
	protected $Passwd = "";
	public $LastErrorMsg = "";
	
	public function __construct ( $wsdl, $options, $UserId, $Passwd )
	{
		parent::__construct($wsdl, $options);
		$this->UserId = $UserId;
		$this->Passwd = $Passwd;
	}
	
	private function SetErrorMsg ( $ErrorCode )
	{
		switch ($ErrorCode)
		{
			case 0:	
				$this->LastErrorMsg = "OK";
				break;
			case 1:
				$this->LastErrorMsg = "account unknown";
				break;
			case 2:
				$this->LastErrorMsg = "access denied";
				break;
			case 3:
				$this->LastErrorMsg = "account expired";
				break;
			case 4:
				$this->LastErrorMsg = "account locked";
				break;
			default:
				$this->LastErrorMsg = "Error " . $ErrorCode;
		}
	}


	private function SetReceiveErrorMsg ( $ErrorCode )
	{
		$this->SetErrorMsg ( $ErrorCode );
		switch ($ErrorCode)
		{
			case 5:
				$this->LastErrorMsg = "no new fax available";
				break;
		}
	}

	private function SetDeleteReceivedErrorMsg ( $ErrorCode )
	{
		$this->SetErrorMsg ( $ErrorCode );
		switch ($ErrorCode)
		{
			case 5:
				$this->LastErrorMsg = "unknown fax id";
				break;
		}
	}

	private function SetSendErrorMsg ( $ErrorCode )
	{
		switch ($ErrorCode)
		{
			case  0:
				$this->SetErrorMsg ( 0 );
				break;
			case -1:
				$this->SetErrorMsg ( 2 );
				break;
			case -2:
				$this->SetErrorMsg ( 1 );
				break;
			case -3:
				$this->LastErrorMsg = "no document";
				break;
			case -4:
				$this->LastErrorMsg = "server error";
				break;
			case -5:
				$this->LastErrorMsg = "recipient number blocked";
				break;
			case -6:
				$this->LastErrorMsg = "unsupported document type";
				break;
			case -7:
			case -14:
			case 58: 
				$this->LastErrorMsg = "error converting document";
				break;
			case -8:
				$this->LastErrorMsg = "not authorized for this destination or job type";
				break;
			case -1309:
				$this->LastErrorMsg = "too many pages ( > 3 ) during evaluation perid";
				break;
			case  1:
				$this->LastErrorMsg = "not authorized";
				break;
			case  2:
				$this->LastErrorMsg = "missing customer id";
				break;
			case  3:
				$this->SetErrorMsg ( 3 );
				break;
			case  4:
				$this->LastErrorMsg = "invalid job type";
				break;
			case  6:
				$this->LastErrorMsg = "credit not yet available";
				break;
			case  7:
				$this->LastErrorMsg = "indufficient credit";
				break;
			case  8:
				$this->LastErrorMsg = "no valid recipient";
				break;
			case  9:
				$this->LastErrorMsg = "recipient blacklisted";
				break;
			case 10:
				$this->LastErrorMsg = "internal error QSign";
				break;
			case 15:
				$this->LastErrorMsg = "no sendfile";
				break;
			case 45:
			case 46:
			case 47:
				$this->LastErrorMsg = "recipient not allowed (premium number)";
				break;
			case 54:
				$this->LastErrorMsg = "no incoming payment";
				break;
			case 61:
				$this->LastErrorMsg = "insufficient excepted quantity";
				break;
			case 75:
				$this->LastErrorMsg = "no given SendText or SendFilei";
				break;

			default:
				$this->LastErrorMsg = "Error " . $ErrorCode;
		}
	}
	
	private function SetStatusErrorMsg ( $ErrorCode )
	{
		$this->SetErrorMsg ( $ErrorCode );
		switch ($ErrorCode)
		{
			case 5:
				$this->LastErrorMsg = "unknown jobid";
				break;
			case 6:
				$this->LastErrorMsg = "job in progress";
				break;
		}
	}

	private function SetQSignGetErrorMsg ( $ErrorCode )
	{
		$this->SetErrorMsg ( $ErrorCode );
		switch ($ErrorCode)
		{
			case 5:
				$this->LastErrorMsg = "job in progress";
				break;
		}
	}
	
	
	public function FaxReceive ( $DropPath , &$FaxId, &$ReceiveDate="", &$Originator="", &$RemoteId="", &$Pages=0 )
	{
		$erg = $this->__soapCall('RequestReceived', array ( $this->UserId, $this->Passwd ));
		$res  = $erg['return'];
		$this->SetReceiveErrorMsg ( $res );
		if ($res==0)
		{

			$FaxId       = $erg['FaxId'];
			$ReceiveDate =  date_create($erg['ReceiveDate']);
			$Originator  = $erg['Originator'];
			$RemoteId    = $erg['RemoteId'];
			$Pages       = $erg['Pages'];

   		$FaxFile = $DropPath . date_format ( $ReceiveDate, 'Y-m-d H-i-s' ) . '-' . $FaxId . '.tif';
			file_put_contents ( $FaxFile, $erg['FaxImage'] );

			echo "new fax saved in $FaxFile\n";
			
		}
		return $res;
  }
    
  public function FaxDelete ( $FaxId )
  {
		$res = $this->__soapCall('DeleteReceived', array ( $this->UserId, $this->Passwd, $FaxId ));
		$this->SetDeleteReceivedErrorMsg ( $res );
		return $res;
  }
    
  public function GetInboundFaxes ( $DropPath )
  {
  	do
   	{
   		$res = $this->FaxReceive ( $DropPath, $FaxFile, $ReceiveDate, $Originator, $RemoteId, $Pages );
   		$HasFax = ( $res == 0 );
   		if ($HasFax)
   		{
   			$this->FaxDelete ( $FaxFile );
   		}
   	}
   	while ($HasFax);
  }
    
	
	public function SendSMS ( $CellPhoneNumber, $Message, $Sender, &$JobId )
	{
		if ($Sender!="")
		  $switch = "SMSFROM=$Sender";
		else
		  $switch = "";
		  
		$erg = $this->__soapCall('SendJob', array ( 	$this->UserId, 
													$this->Passwd, 		
													jobtype_sms, 
													$CellPhoneNumber,
													'',
													$Message,
													'','',
													'','',
													'','',
													0,
													$switch,
													0,
													0,
													0
													 ));
		$res  = $erg['return'];
		$this->SetSendErrorMsg ( $res );
		if ($res==0)
		  $JobId = $erg['JobId'];
		return $res;
		
	}
	
	public function SendSingleFax ( $FaxNumber, $DocumentFile, &$JobId )
	{
		$DocString = file_get_contents( $DocumentFile );

		$erg = $this->__soapCall('SendJob', array ( 	$this->UserId, 
													$this->Passwd, 
													jobtype_fax, 
													$FaxNumber,
													'',
													'',
													$DocumentFile, $DocString,
													'','',
													'','',
													0,
													'',
													0,
													0,
													0
													 ));
		$res  = $erg['return'];
		$this->SetSendErrorMsg ( $res );
		if ($res==0)
		  $JobId = $erg['JobId'];
		return $res;
	}

	public function SendMultipleFax ( $RecipientsFile, $DocumentFile, &$JobId )
	{
		$Recipients = file_get_contents( $RecipientsFile );
		$DocString = file_get_contents( $DocumentFile );

		$erg = $this->__soapCall('SendJob', array ( 	$this->UserId, 
													$this->Passwd, 
													jobtype_fax, 
													'',
													$Recipients,
													'',
													$DocumentFile, $DocString,
													'','',
													'','',
													0,
													'',
													0,
													0,
													0
													 ));
		$res  = $erg['return'];
		$this->SetSendErrorMsg ( $res );
		if ($res==0)
		  $JobId = $erg['JobId'];
		return $res;
	}
	
	public function Status ( $JobId, &$SendResult="", &$SendDateTime="", &$RemoteId="", &$Protokoll="" )
	{
		$erg = $this->__soapCall('JobStatus', array ( $this->UserId, $this->Passwd, $JobId ));
		$res  = $erg['return'];
		$this->SetStatusErrorMsg ( $res );
		if ($res==0)
		{
			$SendResult    = $erg['SendResult'];
			$SendDateTime = date_create($erg['SendDateTime']);
			$RemoteId      = $erg['RemoteId'];
			$Protokoll     = $erg['StatusFile'];
		}
		return $res;
	}

	
}

function CreateFaxdeClient( $UserId, $Passwd ) {
	$client = new faxdeclient ( URL,
				  array(
                			'trace' => 1,
                			'exceptions' => 1,
                			'soap_version' => SOAP_1_1,
                			// php is usually configured to handle UTF-8 charset. If not, set the 
                			// encoding to the charset you are feeding into the soap client.
                			// The client will transform your strings to and from UTF-8 for transfer.
//                			'encoding' => 'ISO-8859-1',
                			'encoding' => 'UTF-8',
                			'features' => SOAP_SINGLE_ELEMENT_ARRAYS
            				),
            			$UserId,
            			$Passwd
            	);
	return $client;
}

?>